@@ -35,7 +35,8 @@
 #include <gnunet/gnunet_arm_service.h>
 
 /**
- * How many block requests can we have outstanding in parallel at a time by default?
+ * How many block requests can we have outstanding in parallel at a time by
+ * default?
  */
 #define DEFAULT_MAX_PARALLEL_REQUESTS 100000
 
@@ -205,7 +206,7 @@ main_window_save_position (GtkWidget *main_window)
                                          "gnunet-fs-gtk",
                                          "MAIN_WINDOW_MAXIMIZED",
                                          (maximized == GNUNET_YES) ? "YES"
-                                         : "NO");
+                                                                   : "NO");
 
   cfgDefault = GNUNET_CONFIGURATION_create ();
   (void) GNUNET_CONFIGURATION_load (cfgDefault, NULL); /* load defaults only */
@@ -300,11 +301,6 @@ shutdown_task (void *cls)
     GNUNET_GNS_disconnect (main_context.gns);
     main_context.gns = NULL;
   }
-  if (NULL != main_context.sks_zone)
-  {
-    GNUNET_free (main_context.sks_zone);
-    main_context.sks_zone = NULL;
-  }
 }
 
 
@@ -454,6 +450,8 @@ unique_app_message_cb (UniqueApp *app,
   }
   return UNIQUE_RESPONSE_OK;
 }
+
+
 #endif
 
 
@@ -663,21 +661,22 @@ handle_sks_zone_identity (void *cls,
         "No default ego specified for `fs-sks` service, will not enable namespace search.\n"));
     return;
   }
-  main_context.sks_zone = GNUNET_new (struct GNUNET_IDENTITY_PrivateKey);
-  *main_context.sks_zone = *GNUNET_IDENTITY_ego_get_private_key (ego);
+  main_context.sks_zone = ego;
   gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
                                  "main_window_search_namespace_label")));
   gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
                                  "main_window_search_namespace_combobox")));
-  main_context.zm = GNUNET_NAMESTORE_zone_monitor_start (main_context.cfg,
-                                                         main_context.sks_zone,
-                                                         GNUNET_YES,
-                                                         &monitor_zone_error,
-                                                         NULL,
-                                                         &monitor_zone_records,
-                                                         NULL,
-                                                         &monitor_zone_sync,
-                                                         NULL);
+  main_context.zm =
+    GNUNET_NAMESTORE_zone_monitor_start (main_context.cfg,
+                                         GNUNET_IDENTITY_ego_get_private_key (
+                                           main_context.sks_zone),
+                                         GNUNET_YES,
+                                         &monitor_zone_error,
+                                         NULL,
+                                         &monitor_zone_records,
+                                         NULL,
+                                         &monitor_zone_sync,
+                                         NULL);
 }
 
 
@@ -735,8 +734,6 @@ run (void *cls)
                       "main_window_search_namespace_treestore"));
   main_context.main_window = GTK_WIDGET (
     GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window"));
-  main_context.main_window =
-    GNUNET_GTK_plug_me ("GNUNET_FS_GTK_PLUG", main_context.main_window);
   main_context.ns_selector_treeview = GTK_TREE_VIEW (
     GNUNET_FS_GTK_get_main_window_object ("namespace_selector_treeview"));
   main_context.ns_selector_window = GTK_WIDGET (
