@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -28,7 +28,9 @@
 
 #include "gnunet_gtk.h"
 #include <gnunet/gnunet_fs_service.h>
+#if HAVE_EXTRACTOR_H
 #include <extractor.h>
+#endif
 
 
 /**
@@ -38,8 +40,8 @@
  * @return NULL on error, otherwise the embedded thumbnail
  */
 GdkPixbuf *
-GNUNET_FS_GTK_get_thumbnail_from_meta_data (const struct
-                                            GNUNET_CONTAINER_MetaData *meta);
+GNUNET_FS_GTK_get_thumbnail_from_meta_data (
+  const struct GNUNET_CONTAINER_MetaData *meta);
 
 
 /**
@@ -74,11 +76,13 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
  * @return 0 to continue (always)
  */
 int
-GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
+GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls,
+                                           const char *plugin_name,
                                            enum EXTRACTOR_MetaType type,
                                            enum EXTRACTOR_MetaFormat format,
                                            const char *data_mime_type,
-                                           const char *data, size_t data_len);
+                                           const char *data,
+                                           size_t data_len);
 
 
 /**
@@ -96,8 +100,8 @@ GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls, const char *plugin_name,
  */
 char *
 GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
-                                    const char *data, size_t data_len);
-
+                                    const char *data,
+                                    size_t data_len);
 
 
 /**
@@ -110,8 +114,9 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
  * @return description of the result in utf-8, never NULL
  */
 char *
-GNUNET_FS_GTK_get_description_from_metadata (const struct GNUNET_CONTAINER_MetaData *meta,
-					     int *is_a_dup);
+GNUNET_FS_GTK_get_description_from_metadata (
+  const struct GNUNET_CONTAINER_MetaData *meta,
+  int *is_a_dup);
 
 
 /**
@@ -123,7 +128,7 @@ GNUNET_FS_GTK_get_description_from_metadata (const struct GNUNET_CONTAINER_MetaD
  */
 void
 GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
-			  guint anonymity_level);
+                          guint anonymity_level);
 
 
 /**
@@ -134,8 +139,7 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
  * @return #GNUNET_OK if iter was filled, #GNUNET_SYSERR otherwise
  */
 int
-GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr,
-				    GtkTreeIter *iter);
+GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr, GtkTreeIter *iter);
 
 
 /**
@@ -146,8 +150,7 @@ GNUNET_GTK_get_iter_from_reference (GtkTreeRowReference *rr,
  * @return newly created reference or NULL in case of error
  */
 GtkTreeRowReference *
-GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model,
-				    GtkTreeIter *iter);
+GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model, GtkTreeIter *iter);
 
 
 /**
@@ -169,9 +172,9 @@ GNUNET_GTK_get_reference_from_iter (GtkTreeModel *model,
  */
 gboolean
 GNUNET_GTK_tree_model_get_next_flat_iter (GtkTreeModel *model,
-					  GtkTreeIter *iter,
-					  gboolean allow_children,
-					  GtkTreeIter *next_iter);
+                                          GtkTreeIter *iter,
+                                          gboolean allow_children,
+                                          GtkTreeIter *next_iter);
 
 
 #endif
